@@ -9,6 +9,7 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 
 import pandas as pd
+import rdflib
 from bioregistry.export.prefix_maps import EXTENDED_PREFIX_MAP_PATH
 
 from curies.api import Converter, DuplicatePrefixes, DuplicateURIPrefixes, Record, chain
@@ -193,6 +194,36 @@ class TestConverter(unittest.TestCase):
             converter.compress("https://www.ebi.ac.uk/chebi/searchId.do?chebiId=138488"),
         )
 
+    def test_standardize_curie(self):
+        """Test standardize CURIE."""
+        converter = Converter.from_extended_prefix_map(
+            [
+                Record(
+                    prefix="CHEBI",
+                    prefix_synonyms=["chebi"],
+                    uri_prefix="http://purl.obolibrary.org/obo/CHEBI_",
+                    uri_prefix_synonyms=[
+                        "https://www.ebi.ac.uk/chebi/searchId.do?chebiId=CHEBI:",
+                    ],
+                ),
+            ]
+        )
+        self.assertEqual("CHEBI:138488", converter.standardize_curie("chebi:138488"))
+        self.assertEqual("CHEBI:138488", converter.standardize_curie("CHEBI:138488"))
+        self.assertIsNone(converter.standardize_curie("NOPE:NOPE"))
+
+        self.assertEqual(
+            "http://purl.obolibrary.org/obo/CHEBI_138488",
+            converter.standardize_uri(
+                "https://www.ebi.ac.uk/chebi/searchId.do?chebiId=CHEBI:138488"
+            ),
+        )
+        self.assertEqual(
+            "http://purl.obolibrary.org/obo/CHEBI_138488",
+            converter.standardize_uri("http://purl.obolibrary.org/obo/CHEBI_138488"),
+        )
+        self.assertIsNone(converter.standardize_uri("NOPE"))
+
     def test_combine(self):
         """Test chaining converters."""
         with self.assertRaises(ValueError):
@@ -343,6 +374,17 @@ class TestConverter(unittest.TestCase):
         with self.assertRaises(ValueError):
             converter.add_prefix("...", "...", prefix_synonyms=["GO"])
 
+    def test_rdflib(self):
+        """Test parsing a converter from an RDFLib object."""
+        graph = rdflib.Graph()
+        for prefix, uri_prefix in self.simple_obo_prefix_map.items():
+            graph.bind(prefix, uri_prefix)
+        converter = Converter.from_rdflib(graph)
+        self._assert_convert(converter)
+
+        converter_2 = Converter.from_rdflib(graph.namespace_manager)
+        self._assert_convert(converter_2)
+
 
 class TestVersion(unittest.TestCase):
     """Trivially test a version."""
